@@ -383,47 +383,7 @@ static void parse_commandline(Options *op, int argc, char *argv[])
             op->metamodes_str = strval;
             break;
 
-        case MULTI_GPU_OPTION:
-            {
-                const char* valid_values[] = {
-                    "0",
-                    "no",
-                    "off",
-                    "false",
-                    "single",
-                    "1",
-                    "yes",
-                    "on",
-                    "true",
-                    "auto",
-                    "afr",
-                    "sfr",
-                    "aa",
-                    NULL
-                };
-                int i;
-
-                /* mark as disabled, so we can remove the option later */
-                
-                if (disable) {
-                    op->multigpu = NV_DISABLE_STRING_OPTION;
-                    break;
-                }
-
-                for (i = 0; valid_values[i]; i++) {
-                    if (!strcasecmp(strval, valid_values[i]))
-                        break;
-                }
-
-                if (valid_values[i]) {
-                    op->multigpu = strval;
-                } else {
-                    fprintf(stderr, "Invalid MultiGPU option: %s.\n", strval);
-                    goto fail;
-                }
-            }
-            break;
-
+        case MULTI_GPU_OPTION: /* fall through */
         case SLI_OPTION:
             {
                 const char* valid_values[] = {
@@ -432,37 +392,35 @@ static void parse_commandline(Options *op, int argc, char *argv[])
                     "off",
                     "false",
                     "single",
-                    "1",
-                    "yes",
-                    "on",
-                    "true",
-                    "auto",
-                    "afr",
-                    "sfr",
-                    "aa",
-                    "afrofaa",
                     "mosaic",
                     NULL
                 };
-                int i;
 
-                /* mark as disabled, so we can remove the option later */
-                
                 if (disable) {
-                    op->sli = NV_DISABLE_STRING_OPTION;
-                    break;
-                }
 
-                for (i = 0; valid_values[i]; i++) {
-                    if (!strcasecmp(strval, valid_values[i]))
-                        break;
-                }
+                    /* mark as disabled, so we can remove the option later */
+                    strval = NV_DISABLE_STRING_OPTION;
 
-                if (valid_values[i]) {
-                    op->sli = strval;
                 } else {
-                    fprintf(stderr, "Invalid SLI option: %s.\n", strval);
-                    goto fail;
+
+                    /* check that the string is valid */
+                    int i;
+
+                    for (i = 0; valid_values[i]; i++) {
+                        if (!strcasecmp(strval, valid_values[i]))
+                            break;
+                    }
+
+                    if (!valid_values[i]) {
+                        fprintf(stderr, "Invalid SLI option: %s.\n", strval);
+                        goto fail;
+                    }
+                }
+
+                if (c == MULTI_GPU_OPTION) {
+                    op->multigpu = strval;
+                } else {
+                    op->sli = strval;
                 }
             }
             break;
@@ -1115,7 +1073,7 @@ static XConfigPtr find_system_xconfig(Options *op)
 /*
  * apply_enable_prime_settings() -  if the ENABLE PRIME boolean option is
  * enabled, add the required xconfig additions.
- * returns a sucess/fail boolean.
+ * returns a success/fail boolean.
  */
 
 static int apply_enable_prime_settings(Options *op, XConfigPtr config,
@@ -1140,6 +1098,37 @@ static int apply_enable_prime_settings(Options *op, XConfigPtr config,
     return TRUE;
 } /* apply_enable_prime_settings() */
 
+/*
+ * apply_enable_external_gpu_option() - if the ENABLE EXTERNAL GPU boolean
+ * option is enabled, add the AllowExternalGpus option to the ServerLayout
+ * section
+ * returns a success/fail boolean
+ */
+
+static int apply_enable_external_gpu_option(Options *op, XConfigPtr config,
+                                            XConfigLayoutPtr layout)
+{
+    int egpu = GET_BOOL_OPTION(op->boolean_option_values,
+                               ENABLE_EXTERNAL_GPU_BOOL_OPTION);
+
+    if (GET_BOOL_OPTION(op->boolean_options, ENABLE_EXTERNAL_GPU_BOOL_OPTION)) {
+        xconfigAddNewOption(&(layout->options),
+                            "AllowExternalGpus",
+                            (egpu ? "1" : "0"));
+
+        if (egpu) {
+            nv_info_msg(NULL, "X configuration file set up to allow detection "
+                              "of External GPUs. If the eGPU does not work, "
+                              "you may need to authorize the associated "
+                              "Thunderbolt device.\n"
+                              "Warning: System may become unstable if the "
+                              "eGPU is hot-unplugged while X is running.\n"
+                              "See \"Configuring External and Removable "
+                              "GPUs\" in the README for more details.");
+        }
+    }
+    return TRUE;
+} /* apply_enable_external_gpu_option */
 
 
 static int update_xconfig(Options *op, XConfigPtr config)
@@ -1167,6 +1156,11 @@ static int update_xconfig(Options *op, XConfigPtr config)
         return FALSE;
     }
 
+    /* apply eGPU setting */
+    if (!apply_enable_external_gpu_option(op, config, layout)) {
+        return FALSE;
+    }
+
     /*
      * update the device and option for all screens, or the screen
      * or device that was requested.
@@ -1250,7 +1244,7 @@ int main(int argc, char *argv[])
     /* parse the commandline */
 
     parse_commandline(op, argc, argv);
-    
+
     /*
      * first, check for any of special options that cause us to exit
      * early
